@@ -4,7 +4,7 @@ isOct=strcmp(logv(1).Name,'Octave');
 if isOct
     pkg load general;
     more off
-    pkg load msh
+%    pkg load msh
     warning('off','Octave:fopen-file-in-path') % disable warning for mesh files in path
 end
 P = strcat(fileparts(mfilename('fullpath')),filesep);
